/*
 *  SPDX-License-Identifier: GPL-2.0-or-later
 *
 *  Copyright (C) 2021-2022  The DOSBox Staging Team
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#include "dosbox.h"

#include <cassert>
#include <string>

const char *DOSBOX_GetDetailedVersion() noexcept
{
	static std::string version = "0.79.1";

	// Return the full tag and hash, if it's not a tag
	if (version[0] != 'v')
		return version.c_str();

	// If it's a tagged alpha, return the version and hash
	const bool is_alpha = version.find("alpha") != std::string::npos;

	if (is_alpha)
		return version.c_str() + 1;

	// If it's a tagged release, return just the tag without the hash
	assert(!is_alpha);
	const auto dash_pos = version.find_first_of("-");
	const auto has_dash = dash_pos != std::string::npos;
	if (has_dash && dash_pos > 1) {
		static const auto tag_no_hash = version.substr(1, dash_pos - 1);
		return tag_no_hash.c_str();
	}

	// If it's none of the above, just return it
	return version.data();
}
